@@ -6,6 +6,7 @@ except ImportError: #For Django 1.3
 
 from django.core.management import call_command
 from django.test import TestCase
+from django.core.urlresolvers import reverse
 
 from bdd4django import Parser
 from splinter.browser import Browser
@@ -55,8 +56,9 @@ class BDDBaseTestCase():
         if file_path is None:
             exec 'import '+app
             file_path = eval('{0}.__path__'.format( app ))[0]
+            file_path = '{0}/{1}.feature'.format( file_path, app )
 
-        Parser().parse_file('{0}/{1}.feature'.format( file_path, app ), scenarios).evaluate(self)
+        Parser().parse_file(file_path, scenarios).evaluate(self)
 
     def today(self,format='%Y-%m-%d', add_days = 0):
         import datetime
@@ -67,7 +69,81 @@ class BDDBaseTestCase():
         return new_dt.strftime( format )
 
 class BDDCoreTestCase(BDDBaseTestCase,TestCase):
-    pass
+
+    def step_I_call_view(self, view):
+        r'I call view "([^"]+)"'
+        self.response = self.client.get( reverse(view) )
+
+    def step_I_call_view_as_user_with_password(self, view, username, password):
+        r'I call view "([^"]+)" as user "([^"]+)" with password "([^"]+)"'
+        self.client.login(username=username, password=password)
+        self.step_I_call_view(view)
+
+    def step_I_get_the_template_rendered(self, template_name):
+        r'I get the template "([^"]+)" rendered'
+        self.assertTemplateUsed( self.response, template_name=template_name )
+
+    def step_I_call_view_with_data(self, view, type, data):
+        r'I call view "([^"]+)" with ([^"]+) data "([^"]+)"'
+        if type.lower() == 'post':
+            method = self.client.post
+        else:
+            method = self.client.get
+
+        data = eval( data )
+
+        self.response = method( reverse(view), data=data )
+
+    def step_I_call_view_with_data_as_user_with_password(self, view, type, data, username, password):
+        r'I call view "([^"]+)" with ([^"]+) data "([^"]+)" as user "([^"]+)" with password "([^"]+)"'
+        self.client.login(username=username, password=password)
+        self.step_I_call_view_with_data( view, type, data )
+
+    def step_I_see_an_object_with_values(self, object, values):
+        r'I see an object "([^"]+)" with values "([^"]+)"'
+        obj = None
+
+        last_dot = object.rfind('.')
+        if last_dot >= 0:
+            modules = object[:last_dot]
+            model   = object[last_dot+1:]
+        else:
+            app = self.__module__.split('.')[0]
+
+            modules = app+'.models'
+            model   = object
+
+        exec( 'from {0} import {1}'.format( modules, model ) )
+        exec( 'obj = '+object )
+        values = eval( values )
+
+        self.assertGreater( obj.objects.filter(**values), 0 )
+
+    def step_I_get_the_context_variables_with_values(self, variables, values):
+        r'I get the context variables "([^"]+)" with values "([^"]+)"'
+
+        variables = variables.split('|')
+        values    = values.split('|')
+
+        len_varibales = len(variables)
+        len_values     = len(values)
+
+        if len_varibales != len_values:
+            raise Exception( 'Number of variables (%i) doesn\'t match number of values (%i)' % ( len_varibales, len_values ) )
+
+        for i in range(0, len_varibales):
+            vars = variables[i].split('.')
+
+            if len(vars) > 1:
+                self.assertEqual(  eval( 'self.response.context["{0}"].{1}'.format( vars[0],'.'.join(vars[1:]) ) ),  eval(values[i]) )
+            else:
+                self.assertEqual(  eval( 'self.response.context["{0}"]'.format( vars[0] ) ),  eval(values[i]) )
+
+    def step_I_see_the_text_in_template(self, text):
+        r'I see the text "([^"]+)" in template'
+        self.assertContains( self.response, text )
+
+
 
 class BDDTestCase(BDDBaseTestCase, LiveServerTestCase):
 
